defmodule Forum.User do
  use Ecto.Schema
  use Tesla
  import Ecto.Changeset
  alias Forum.User

  plug(Tesla.Middleware.BaseUrl, "https://tilde.team")

  schema "users" do
    field(:bio, :string)
    field(:name, :string)
    field(:sudoer, :boolean)

    timestamps()
  end

  @doc false
  def changeset(%User{} = user, attrs) do
    user
    |> cast(attrs, [:name, :bio, :sudoer])
    |> validate_required([:name, :bio])
    |> unique_constraint(:name)
  end

  @doc """
  Gets contents of tagline.txt for user
  """
  def tagline(user) do
    {:ok, resp} = get("~#{user.name}/tagline.txt")

    case resp.status do
      200 ->
        resp.body

      404 ->
        "no tagline found. put something in ~/public_html/tagline.txt!"

      _ ->
        "something went wrong..."
    end
  end

  @doc """
  Gets tilde url for user
  """
  def profile_url(user) do
    "https://tilde.team/~#{user.name}/"
  end

  @doc """
  Gets path to avatar for user
  """
  def pfp(user) do
    profile_url(user) <> "avatar.png"
  end
end
