defmodule ForumWeb.PostController do
  use ForumWeb, :controller

  alias Forum.Post

  def create(conn, %{"post" => post_params}) do
    case Forum.create_post(post_params) do
      {:ok, post} ->
        Post.handle_mentions(post)

        conn
        |> put_flash(:info, "reply created successfully.")
        |> redirect(to: thread_path(conn, :show, post.thread_id))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(
          conn,
          "new.html",
          changeset: changeset,
          user_id: Forum.get_user_id_by_name(Util.current_username(conn)),
          thread_id: post_params["thread_id"]
        )
    end
  end

  def edit(conn, %{"id" => id}) do
    post = Forum.get_post!(id)
    changeset = Forum.change_post(post)

    render(
      conn,
      "edit.html",
      post: post,
      changeset: changeset,
      page_title: "edit post // forum.tilde.team"
    )
  end

  def update(conn, %{"id" => id, "post" => post_params}) do
    post = Forum.get_post!(id)

    case Forum.update_post(post, post_params) do
      {:ok, post} ->
        conn
        |> put_flash(:info, "reply updated successfully.")
        |> redirect(to: thread_path(conn, :show, post.thread.id))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "edit.html", post: post, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}) do
    post = Forum.get_post!(id)
    thread_id = post.thread.id
    {:ok, _post} = Forum.delete_post(post)

    conn
    |> put_flash(:info, "reply deleted successfully.")
    |> redirect(to: thread_path(conn, :show, thread_id))
  end
end
