defmodule ForumWeb.UserController do
  use ForumWeb, :controller

  alias Forum.Repo
  alias Forum.User

  def index(conn, params) do
    {users, kerosene} =
      User
      |> Repo.paginate(params)

    render(
      conn,
      "index.html",
      users: users,
      kerosene: kerosene,
      page_title: "forum users"
    )
  end

  def new(conn, _params) do
    changeset = Forum.change_user(%User{})
    render(conn, "new.html", changeset: changeset)
  end

  def create(conn, %{"user" => user_params}) do
    case Forum.create_user(user_params) do
      {:ok, user} ->
        conn
        |> put_flash(:info, "user created successfully.")
        |> redirect(to: user_path(conn, :show, user.name))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "new.html", changeset: changeset)
    end
  end

  def show(conn, %{"name" => name}) do
    user = Forum.get_user!(name)

    render(
      conn,
      "show.html",
      user: user,
      page_title: "~#{name} // forum.tilde.team",
      tagline: User.tagline(user)
    )
  end

  def edit(conn, %{"name" => name}) do
    user = Forum.get_user!(name)

    if user.name == Util.current_username(conn) do
      changeset = Forum.change_user(user)
      render(conn, "edit.html", user: user, changeset: changeset)
    else
      conn
      |> put_flash(:info, "you can't edit someone else's profile, silly")
      |> redirect(to: user_path(conn, :show, user.name))
    end
  end

  def update(conn, %{"name" => name, "user" => user_params}) do
    user = Forum.get_user!(name)

    if Util.can_edit?(conn, user) do
      case Forum.update_user(user, user_params) do
        {:ok, user} ->
          conn
          |> put_flash(:info, "user updated successfully.")
          |> redirect(to: user_path(conn, :show, user.name))

        {:error, %Ecto.Changeset{} = changeset} ->
          render(conn, "edit.html", user: user, changeset: changeset)
      end
    else
      conn
      |> put_flash(:info, "you can't edit someone else's profile, silly")
      |> redirect(to: user_path(conn, :show, user.name))
    end
  end

  def delete(conn, %{"name" => name}) do
    user = Forum.get_user!(name)
    {:ok, _user} = Forum.delete_user(user)

    conn
    |> put_flash(:info, "user deleted successfully.")
    |> redirect(to: user_path(conn, :index))
  end
end
