defmodule ForumWeb.Router do
  use ForumWeb, :router

  if Mix.env() == :dev do
    forward("/sent_emails", Bamboo.EmailPreviewPlug)
  end

  pipeline :browser do
    plug(:accepts, ["html"])
    plug(:fetch_session)
    plug(:fetch_flash)
    plug(:protect_from_forgery)
    plug(:put_secure_browser_headers)
  end

  pipeline :restricted do
    plug(:browser)
    plug(ForumWeb.Plugs.RequireAuth)
  end

  scope "/auth", ForumWeb do
    pipe_through(:browser)

    get("/", LoginController, :index)
    get("/logout", LoginController, :logout)
    post("/", LoginController, :authenticate)
  end

  scope "/", ForumWeb do
    pipe_through(:restricted)

    get("/", ThreadController, :index)
    resources("/u", UserController, except: [:new], param: "name")
    resources("/threads", ThreadController)
    resources("/posts", PostController, except: [:index, :new, :show])
  end
end
